@@ -3,6 +3,7 @@ expEYES data analysis library using numpy and scipy
 Author  : Ajith Kumar B.P, bpajith@gmail.com
 License : GNU GPL version 3
 '''
+from __future__ import print_function
 
 import sys, time, math
 from numpy import *
@@ -50,7 +51,7 @@ def find_frequency(x,y):		# Returns the fundamental frequency using FFT
 	mx = max(ty)
 	for i in range(1,len(ty)):
 		if ty[i] != 0:
-			print 'FF', tx[i], ty[i]
+			print ('FF', tx[i], ty[i])
 		if ty[i] > 5*m:
 			return tx[i]
 	return None					# Could not find FFT Peak
@@ -71,7 +72,7 @@ def fit_sine(xlist,ylist, freq = 0):	# Time in mS, V in volts, freq in Hz
 		freq = find_frequency(xa,ya)
 	if freq == None:
 		return None
-	#print 'guess a & freq = ', amp, freq
+	#print ('guess a & freq = ', amp, freq)
 	par = [abs(amp), freq*0.001, 0.0, 0.0] # Amp, freq, phase , offset
 	plsq = leastsq(sine_erf, par,args=(ya,xa))
 	if plsq[0][0] < 0:
@@ -81,10 +82,10 @@ def fit_sine(xlist,ylist, freq = 0):	# Time in mS, V in volts, freq in Hz
 		return None
 	yfit = sine_eval(xa, plsq[0])
 	#if plsq[0][0] < 0:
-	    #print plsq[0]
+	    #print (plsq[0])
 	    #plsq[0][0] *= -1
 	    #plsq[0][2] += pi
-	    #print plsq[0]
+	    #print (plsq[0])
 	return yfit,plsq[0]
 
 #--------------------------Damped Sine Fit ------------------------------------------------
@@ -116,7 +117,7 @@ def fit_dsine(xlist, ylist, freq = 0, mode="kHz"):
 		freq = find_frequency(xa,ya)
 		if mode=="Hz":
 			freq=freq/1000
-	print freq
+	print (freq)
 	par = [amp, freq, 0.0, 0.0, 0.1] # Amp, freq, phase , offset, decay constant
 	plsq = leastsq(dsine_erf, par,args=(ya,xa))
 	if plsq[1] > 4:
